import{O as r}from"./workspaceStore.4f93991b.js";import{d as c,X as l,o as i,Y as u,b as a,w as o,u as d,aG as n,dd as f,dc as _}from"./index.9cc3d5c7.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b01d140c-c7d6-409c-9647-8c9d204ea3a9",e._sentryDebugIdIdentifier="sentry-dbid-b01d140c-c7d6-409c-9647-8c9d204ea3a9")}catch{}})();const w=c({__name:"OidcLogoutCallback",setup(e){return l(async()=>{await new r().logoutCallback()}),(t,s)=>(i(),u("div",null,[a(d(f),null,{default:o(()=>[n("You're authenticated")]),_:1}),a(d(_),null,{default:o(()=>[n(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.c95d5b80.js.map
