.editor-layout[data-v-535b1e91]{width:100%;height:100%;padding:10px 20px;display:flex;gap:20px;overflow:hidden;box-sizing:border-box}.editor-layout .layout-left[data-v-535b1e91],.editor-layout .layout-center[data-v-535b1e91],.editor-layout .layout-right[data-v-535b1e91]{height:100%;box-sizing:border-box;display:flex;flex-direction:column}.editor-layout .layout-left[data-v-535b1e91]{width:40%}.editor-layout .layout-center[data-v-535b1e91]{width:35%}.editor-layout .layout-right[data-v-535b1e91]{width:25%}[data-v-6ab7b6d0]:root{--main-font-family: DM Sans, sans-serif}[data-v-6ab7b6d0]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-6ab7b6d0]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-6ab7b6d0]{background-color:#fff;padding:10px}.suggestions-container[data-v-6ab7b6d0]{height:100%;padding:8px}.suggestions-container .suggestion[data-v-6ab7b6d0]{display:flex;align-items:center;gap:8px;border-radius:8px;background-color:#f9fafb;padding:16px 8px;cursor:pointer;transition:all .2s}.suggestions-container .suggestion.disabled[data-v-6ab7b6d0]{pointer-events:none;opacity:.5}.suggestions-container .suggestion[data-v-6ab7b6d0]:hover{background-color:#f3f3f3}.suggestions-container .suggestion .icon[data-v-6ab7b6d0]{height:24px;width:24px;color:#d14056}.suggestions-container .suggestion .title[data-v-6ab7b6d0]{font-size:15px;color:#000}[data-v-8492f535]:root{--main-font-family: DM Sans, sans-serif}[data-v-8492f535]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-8492f535]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-8492f535]{background-color:#fff;padding:10px}.smart-chat[data-v-8492f535]{display:flex;flex-direction:column;width:100%;height:100%;margin:0;padding:0;border-radius:4px}.smart-chat.disabled[data-v-8492f535]{opacity:.75;pointer-events:none}.smart-chat-body[data-v-8492f535]{display:flex;flex-direction:column;height:100%;padding:0 8px;flex-grow:1;overflow-y:scroll;word-break:break-word}.smart-chat-body[data-v-8492f535]::-webkit-scrollbar{display:none}.smart-chat-body .entry[data-v-8492f535]{padding-top:4px;padding-bottom:16px}.smart-chat-body .entry .entry-owner[data-v-8492f535]{display:flex;gap:4px;align-items:center;margin-bottom:4px}.action-icons svg[data-v-8492f535]{cursor:pointer;color:#000}.action-icons .filled[data-v-8492f535]{color:#d14056;pointer-events:none}.action-icons .disabled[data-v-8492f535]{opacity:.5;pointer-events:none}.smart-chat-input-wrapper[data-v-8492f535]{display:flex;align-items:center;justify-content:space-between;margin-bottom:16px}.clear-messages-button[data-v-8492f535]{display:flex;align-items:center;justify-content:center;padding:0;margin:8px 4px;width:24px;height:24px;border-radius:50%}.smart-chat-input[data-v-8492f535]{display:flex;flex:1;align-items:end;margin:0 0 0 8px;border:1px solid #d9d9d9;border-radius:8px;padding:8px 8px 8px 12px;max-height:200px;min-height:16px;overflow-x:hidden;overflow-y:hidden;position:relative;box-shadow:#0003 0 0 4px;outline:rgb(209,64,86) solid 0px;transition:outline-width .15s}.smart-chat-input.disabled[data-v-8492f535]{opacity:.5;outline:none}.smart-chat-input[data-v-8492f535]:focus-within,.smart-chat-input[data-v-8492f535]:active{border-color:#fff;outline-width:2px}.smart-chat-input .input-text[data-v-8492f535]{max-height:200px;width:calc(100% - 24px);color:#000;line-height:17px;overflow-y:scroll;overflow-x:hidden;white-space:pre-line;margin-right:10px;-ms-overflow-style:none;scrollbar-width:none}.smart-chat-input .input-text[data-v-8492f535]::-webkit-scrollbar{display:none}.smart-chat-input .input-text[data-v-8492f535]:focus{outline:none}.smart-chat-input .icon[data-v-8492f535]{cursor:pointer;outline:none}.smart-chat-input .icon.disabled[data-v-8492f535]{opacity:.2;pointer-events:none}.smart-chat-input .icon[data-v-8492f535]:hover{background:rgba(255,255,255,.2);border-radius:4px}.scroll-to-bottom[data-v-8492f535]{display:flex;align-items:center;justify-content:center;position:absolute;right:8px;bottom:75px;width:32px;height:32px;background:white;border-radius:50%;padding:4px;box-shadow:#0003 0 0 4px}pre code.hljs{display:block;overflow-x:auto;padding:1em}code.hljs{padding:3px 5px}/*!
  Theme: GitHub Dark
  Description: Dark theme as seen on github.com
  Author: github.com
  Maintainer: @Hirse
  Updated: 2021-05-15

  Outdated base version: https://github.com/primer/github-syntax-dark
  Current colors taken from GitHub's CSS
*/.hljs{color:#c9d1d9;background:#0d1117}.hljs-doctag,.hljs-keyword,.hljs-meta .hljs-keyword,.hljs-template-tag,.hljs-template-variable,.hljs-type,.hljs-variable.language_{color:#ff7b72}.hljs-title,.hljs-title.class_,.hljs-title.class_.inherited__,.hljs-title.function_{color:#d2a8ff}.hljs-attr,.hljs-attribute,.hljs-literal,.hljs-meta,.hljs-number,.hljs-operator,.hljs-variable,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-id{color:#79c0ff}.hljs-regexp,.hljs-string,.hljs-meta .hljs-string{color:#a5d6ff}.hljs-built_in,.hljs-symbol{color:#ffa657}.hljs-comment,.hljs-code,.hljs-formula{color:#8b949e}.hljs-name,.hljs-quote,.hljs-selector-tag,.hljs-selector-pseudo{color:#7ee787}.hljs-subst{color:#c9d1d9}.hljs-section{color:#1f6feb;font-weight:700}.hljs-bullet{color:#f2cc60}.hljs-emphasis{color:#c9d1d9;font-style:italic}.hljs-strong{color:#c9d1d9;font-weight:700}.hljs-addition{color:#aff5b4;background-color:#033a16}.hljs-deletion{color:#ffdcd7;background-color:#67060c}[data-v-7ac6d417]:root{--main-font-family: DM Sans, sans-serif}[data-v-7ac6d417]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-7ac6d417]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-7ac6d417]{background-color:#fff;padding:10px}.header[data-v-7ac6d417]{background:#414a58;padding:2px 20px;color:#fff}.header .toggle-button[data-v-7ac6d417]{display:flex;border-radius:6px}.header .toggle-button[data-v-7ac6d417]:hover{background-color:#fff3}.header .toggle-button .icon[data-v-7ac6d417]{transform:rotate(90deg);cursor:pointer;padding:5px;color:#fff;font-size:20px}.header .toggle-button .icon[data-v-7ac6d417]:not(.open){transform:rotate(-90deg);transition:transform .4s ease}[data-v-362b569c]:root{--main-font-family: DM Sans, sans-serif}[data-v-362b569c]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-362b569c]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-362b569c]{background-color:#fff;padding:10px}.terminal[data-v-362b569c]{background:#272d35;padding:12px 20px;box-sizing:border-box;position:relative}.terminal .resize-handler[data-v-362b569c]{position:absolute;top:0;left:0;right:0;height:4px;transform:translateY(-50%);cursor:ns-resize;background:transparent}.terminal .resize-handler[data-v-362b569c]:hover,.terminal .resize-handler.resizing[data-v-362b569c]{background:#777}.terminal .cli[data-v-362b569c]{height:100%}.terminal .cli .left[data-v-362b569c]{font-family:Courier New,Courier,monospace;height:100%;width:calc(100% - 40px)}.terminal .cli .left .entries[data-v-362b569c]{display:flex;flex-direction:column;flex-grow:1;overflow-y:scroll;color:#fff}.terminal .cli .left .entries[data-v-362b569c]::-webkit-scrollbar{display:none}.terminal .cli .left .entries .entry[data-v-362b569c]{padding:4px 8px}.terminal .cli .left .entries .entry.stderr[data-v-362b569c],.terminal .cli .left .entries .entry.stdout[data-v-362b569c]{font-family:monospace;white-space:pre-line}.terminal .cli .left .entries .entry.stderr[data-v-362b569c]{color:#f37971}.terminal .cli .left .entries .entry.stdout[data-v-362b569c]{color:#a5dbb7}.terminal .cli .left .entries .entry.ai-output[data-v-362b569c]{color:#e2f371}.terminal .cli .left .entries .icons[data-v-362b569c]{margin-top:-6px;margin-bottom:12px}.terminal .cli .left .entries .icons svg[data-v-362b569c],.terminal .cli .left .entries .icons .icon[data-v-362b569c]{cursor:pointer;padding:2px;border-radius:6px;outline:none;color:#aaa}.terminal .cli .left .entries .icons svg[data-v-362b569c]:hover,.terminal .cli .left .entries .icons .icon[data-v-362b569c]:hover{background:rgba(255,255,255,.2);color:#fff}.terminal .cli .left .entries .icons .filled[data-v-362b569c]{color:#fff;pointer-events:none}.terminal .cli .left .entries .icons .disabled[data-v-362b569c]{opacity:.8;pointer-events:none}.terminal .cli .left .entries .local-entry[data-v-362b569c]{white-space:pre-line;width:100%;overflow-wrap:break-word}.terminal .cli .left .entries .loading[data-v-362b569c]{align-self:center}.terminal .cli .right[data-v-362b569c]{width:30px;margin-left:5px;padding:10px 0}.terminal .cli .right .broom-icon[data-v-362b569c]{cursor:pointer;color:#aaa;outline:none}.terminal .cli .right .broom-icon[data-v-362b569c]:hover{color:#fff}.typing-img[data-v-362b569c]{width:36px;margin:0 0 -10px 20px}.clickable[data-v-18856675]{cursor:pointer;display:flex;align-items:center;gap:10px}.file-path[data-v-18856675]{max-width:360px;margin:0;padding:0;text-align:left;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;direction:rtl}
