import{d as a,o,Y as s,b as d,u as r,by as _,a0 as c}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="30fbc842-e90a-48eb-9e7b-a41fd2033416",e._sentryDebugIdIdentifier="sentry-dbid-30fbc842-e90a-48eb-9e7b-a41fd2033416")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.2b101619.js.map
