import{C as r}from"./gateway.22c5659c.js";import"./index.9cc3d5c7.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="a43cecac-5673-4599-a427-5639dbfca440",a._sentryDebugIdIdentifier="sentry-dbid-a43cecac-5673-4599-a427-5639dbfca440")}catch{}})();class d{async list(e){return r.get(`organizations/${e}/folders`)}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return r.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return r.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{d as F};
//# sourceMappingURL=folder.472ab11b.js.map
