import{cM as o}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="c3c62356-709a-40a9-975b-94ad313f8584",e._sentryDebugIdIdentifier="sentry-dbid-c3c62356-709a-40a9-975b-94ad313f8584")}catch{}})();const d=(e,r,n)=>{o.error({message:e,description:r,onClick:n})};export{d as p};
//# sourceMappingURL=popupNotifcation.37bbe14e.js.map
