import{C as n,A as f}from"./CollapsePanel.b227d544.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="42b1300f-ce1f-43ab-87f0-5df61ae3b5a9",e._sentryDebugIdIdentifier="sentry-dbid-42b1300f-ce1f-43ab-87f0-5df61ae3b5a9")}catch{}})();n.Panel=f;n.install=function(e){return e.component(n.name,n),e.component(f.name,f),e};
//# sourceMappingURL=index.f834e9cf.js.map
