import{d as i,o as p,c as n,w as m,b as s,u as t}from"./index.9cc3d5c7.js";import"./linters.bf5c3266.js";import{W as a}from"./workspaces.b6173175.js";import{C as f}from"./ContentLayout.99fbdc50.js";import{a as d}from"./controller.07e1a1cc.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.4daf01a6.js";import"./asyncComputed.c4d23a56.js";import"./workspaceStore.4f93991b.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";import"./record.6b6ff6df.js";import"./gateway.22c5659c.js";import"./popupNotifcation.37bbe14e.js";import"./fetch.595164c1.js";import"./PhPencil.vue.31c50786.js";import"./SaveButton.f59aa3c3.js";import"./UnsavedChangesHandler.691b83c2.js";import"./ExclamationCircleOutlined.1d68d607.js";import"./CrudView.9ca73714.js";import"./router.72eb9cf0.js";import"./Badge.7e1554af.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.de8ed59e.js";import"./BookOutlined.548b6b44.js";import"./PhDotsThreeVertical.vue.a9a966a9.js";import"./index.14f6514a.js";import"./index.ccd42e69.js";import"./polling.36f8aa1b.js";import"./index.4553cf4e.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="f5767bcf-f141-4fdc-be01-6b8895473c55",o._sentryDebugIdIdentifier="sentry-dbid-f5767bcf-f141-4fdc-be01-6b8895473c55")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new d;return(e,u)=>(p(),n(f,null,{default:m(()=>[s(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.1ec209ac.js.map
