import{d as l,em as c,f as r,o,Y as t,S as d,ei as p,ea as u,a0 as _}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c987b8d0-a4d6-4c50-89da-cee5927daae8",e._sentryDebugIdIdentifier="sentry-dbid-c987b8d0-a4d6-4c50-89da-cee5927daae8")}catch{}})();const g={class:"logo"},m=["src","alt"],f=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"4521d904":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",g,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,m)):d("",!0),s.hideText?d("",!0):(o(),t("span",{key:1,class:p(s.size)},u(s.brandName),3))]))}});const h=_(f,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.7574eec6.js.map
