import{k as n,T as a,m as r,P as o,C as p,M as c,s as d,n as s,p as f,q as m,t as u,v as g}from"./index.9cc3d5c7.js";import{s as y,c as l,a as i}from"./workspaceStore.4f93991b.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.a4647f08.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";import"./PlayerConfigProvider.0cbe774c.js";import"./index.fbebfd89.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="89c00a02-777f-4405-8937-9b2f905534fc",t._sentryDebugIdIdentifier="sentry-dbid-89c00a02-777f-4405-8937-9b2f905534fc")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=n({render:()=>f(b)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",d),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.a15aa929.js.map
