import{a0 as t,r as c,o as s,c as r}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="77bb8531-321f-4d19-9a44-40bc81fbc28a",e._sentryDebugIdIdentifier="sentry-dbid-77bb8531-321f-4d19-9a44-40bc81fbc28a")}catch{}})();const _={};function d(e,o){const n=c("RouterView");return s(),r(n,{class:"router"})}const f=t(_,[["render",d],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.5e20639e.js.map
