import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.ca09659f.js";import{L as d}from"./tasksController.44c6b0fb.js";import{d as f,e as u,o as _,c as m,w as t,b as s,u as o,dd as b,aG as i,bT as y,dh as k,a0 as w}from"./index.9cc3d5c7.js";import{C as T}from"./ContentLayout.99fbdc50.js";import{a as g}from"./ant-design.4e4293d3.js";import"./metadata.e2fe8261.js";import"./PhRobot.vue.3af892e7.js";import"./PhWebhooksLogo.vue.fea644af.js";import"./string.22f3398b.js";import"./dayjs.7f223437.js";import"./index.14f6514a.js";import"./gateway.22c5659c.js";import"./popupNotifcation.37bbe14e.js";import"./linters.bf5c3266.js";import"./asyncComputed.c4d23a56.js";import"./scripts.b63dbabe.js";import"./record.6b6ff6df.js";import"./polling.36f8aa1b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6e003a5b-2532-48ab-9b87-b0635c55c8eb",e._sentryDebugIdIdentifier="sentry-dbid-6e003a5b-2532-48ab-9b87-b0635c55c8eb")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new d,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(_(),m(T,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(b),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(y),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.36f598e8.js.map
