import{d as n,o as s,Y as d,a,$ as f,ei as c,a0 as r}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7f16c6c8-e87c-43fb-b95c-fd84fff1448d",e._sentryDebugIdIdentifier="sentry-dbid-7f16c6c8-e87c-43fb-b95c-fd84fff1448d")}catch{}})();const l={class:"content-layout"},_=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(s(),d("div",l,[a("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[f(t.$slots,"default",{},void 0,!0)],2)]))}});const i=r(_,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.99fbdc50.js.map
