import{O as r}from"./workspaceStore.4f93991b.js";import{d as i,X as l,o as c,Y as u,b as a,w as n,u as o,aG as d,dd as f,dc as b}from"./index.9cc3d5c7.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="82d848fb-6ece-4082-aecb-81a4e96fd0ae",e._sentryDebugIdIdentifier="sentry-dbid-82d848fb-6ece-4082-aecb-81a4e96fd0ae")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(c(),u("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.5b033755.js.map
