import{P as f}from"./PlayerNavbar.530f35cf.js";import{d as g,eF as h,ec as i,e as y,f as b,r as k,o as c,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.9cc3d5c7.js";import{u as V}from"./workspaceStore.4f93991b.js";import"./metadata.e2fe8261.js";import"./PhRobot.vue.3af892e7.js";import"./PhWebhooksLogo.vue.fea644af.js";import"./LoadingOutlined.3c7ab847.js";import"./PhSignOut.vue.348b03f4.js";import"./index.60d46dfe.js";import"./Avatar.968b4249.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="9ee04f3f-a4b4-45d7-9a24-b1a76e329852",o._sentryDebugIdIdentifier="sentry-dbid-9ee04f3f-a4b4-45d7-9a24-b1a76e329852")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=i().path,a=y(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!i().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.0aa2bb19.js.map
