import{L as n}from"./Logo.7574eec6.js";import{d as a,o as r,c as d,u as i}from"./index.9cc3d5c7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="49d7cd50-5356-4d72-b2ca-1f6781202437",e._sentryDebugIdIdentifier="sentry-dbid-49d7cd50-5356-4d72-b2ca-1f6781202437")}catch{}})();const f="/assets/logo.0faadfa2.svg",u=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(n,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.3ed6adf3.js.map
