import"./index.9cc3d5c7.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="fccf6e0d-1e2b-41c0-8f7d-8f626a0b8cb0",x._sentryDebugIdIdentifier="sentry-dbid-fccf6e0d-1e2b-41c0-8f7d-8f626a0b8cb0")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.1e4f8875.js.map
