import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.ca09659f.js";import{R as f}from"./tasksController.44c6b0fb.js";import{d as _,ec as b,f as y,o as n,Y as g,b as w,w as k,u as l,c as I,S as T,aS as v,aG as B,dd as S}from"./index.9cc3d5c7.js";import"./gateway.22c5659c.js";import{a as j,B as x}from"./build.1b69c1fa.js";import{a as C}from"./project.7816a4cf.js";import"./tables.76f4fbaa.js";import{a as D}from"./asyncComputed.c4d23a56.js";import"./metadata.e2fe8261.js";import"./PhRobot.vue.3af892e7.js";import"./PhWebhooksLogo.vue.fea644af.js";import"./ant-design.4e4293d3.js";import"./string.22f3398b.js";import"./dayjs.7f223437.js";import"./index.14f6514a.js";import"./linters.bf5c3266.js";import"./scripts.b63dbabe.js";import"./record.6b6ff6df.js";import"./polling.36f8aa1b.js";import"./popupNotifcation.37bbe14e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5d663143-93d7-40a2-bacd-c90a21843a93",e._sentryDebugIdIdentifier="sentry-dbid-5d663143-93d7-40a2-bacd-c90a21843a93")}catch{}})();const U=_({__name:"Tasks",setup(e){const a=b().params.projectId,d=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(c=>c.latest);if(!r)return null;const[p,u]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:p,project:u}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(l(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:l(d),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.2c63ba03.js.map
