import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.faed1b14.js";import{d as m,eF as f,ec as g,o as y,Y as b,b as w,u as n,a0 as k}from"./index.9cc3d5c7.js";import{u as h}from"./workspaceStore.4f93991b.js";import"./Logo.7574eec6.js";import"./string.22f3398b.js";import"./OTPInput.1494fc4e.js";import"./index.4553cf4e.js";import"./url.185ef886.js";import"./colorHelpers.eaccab40.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="13d00e32-ad95-42a9-a794-29ec98620506",e._sentryDebugIdIdentifier="sentry-dbid-13d00e32-ad95-42a9-a794-29ec98620506")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),a=g(),t=h(),_=async()=>{const{redirect:r,...s}=a.query;if(r){await o.push({path:r,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(r,s)=>{var c,d,u,p,i;return y(),b("div",v,[w(l,{"logo-url":(d=(c=n(t).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(u=n(t).state.workspace)==null?void 0:u.brandName,locale:(i=(p=n(t).state.workspace)==null?void 0:p.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.9d12e0d5.js.map
